//**********************************************************************
//  DLMS/COSEM components
//
//  i-cube, Christian Aymon, 1966 Ayent, Switzerland
//          www.icube.ch
//
// (C)Copyright 2001-2016
//**********************************************************************
#ifndef EZHDLCInterface_H
#define EZHDLCInterface_H

#ifdef EZHDLC_EXPORTS
#define EZHDLC_API __declspec(dllexport)
#else
#define EZHDLC_API
#endif

#include "HDLCCallBack.h"

// HDLC parameters
struct THDLCParameters
{
  int ClientMACAddress;
  int ServerAddressSize;
  int ServerUpperMACAddressValue;
  int ServerLowerMACAddressValue;
  THDLCPutBytesProc PutBytesCallback;
  THDLCGetByteProc GetByteCallBack;
  THDLCStateChangeProc StateChangeCallBack;
  void * HDLCObject;
};



// HDLC error codes
struct THDLCStatus
{
  int ErrorKind;
  char ErrorMessage[256];
} ;

const int HDLC_NO_ERROR = 0x0;
const int HDLC_ERROR = 0x1;


// HDLC status
const int HDLC_NDM = 0x0;
const int HDLC_NRM = 0x1;

// HDLC buffer and related functions
typedef void *THDLCBuffer;

// Buffer function
extern "C" EZHDLC_API int HDLCBufferSize(THDLCBuffer Buffer);

extern "C" EZHDLC_API const unsigned char *HDLCBufferData(THDLCBuffer Buffer);

extern "C" EZHDLC_API void HDLCReleaseBuffer(THDLCBuffer *pBuffer);


// Instance creation / destruction
extern "C" EZHDLC_API void HDLCCreateInstance(THDLCParameters *pInstance);

extern "C" EZHDLC_API void HDLCDestroyInstance(THDLCParameters *pInstance);


// Transfer functions
extern "C" EZHDLC_API void HDLCConnect(THDLCParameters *pInstance, THDLCStatus  *pHDLCStatus);

extern "C" EZHDLC_API void HDLCDisconnect(THDLCParameters *pInstance, THDLCStatus *HDLCStatus);

extern "C" EZHDLC_API void HDLCSendReceive(THDLCParameters *pInstance, const unsigned char *pOutData, int iOutDataSize,
	THDLCBuffer *InData, THDLCStatus *pHDLCStatus);

extern "C" EZHDLC_API void HDLCPoll(THDLCParameters *pInstance, THDLCStatus  *pHDLCStatus);

extern "C" EZHDLC_API bool HDLCGetPushedAPDU(THDLCParameters *pInstance, THDLCBuffer *InData, THDLCStatus *pHDLCStatus);

// Misc functions
extern "C" EZHDLC_API int HDLCState(THDLCParameters *pInstance);

extern "C" EZHDLC_API const char *HDLCVersion();

#endif
